@@ -2,7 +2,7 @@ import uvicorn
 from fastapi import FastAPI
 
 from superlinked.server.app import ServerApp
-from superlinked.server.configuration.settings import Settings
+from superlinked.server.configuration.settings import settings
 from superlinked.server.logger import ServerLoggerConfigurator
 
 
@@ -11,7 +11,6 @@ def get_app() -> FastAPI:
 
 
 def main() -> None:
-    settings = Settings()
     ServerLoggerConfigurator.setup_logger(settings)
     uvicorn.run(
         "superlinked.server.__main__:get_app",
