@@ -63,3 +63,8 @@ class Settings(YamlBasedSettings):
     model_config = SettingsConfigDict(
         yaml_file=YAML_FILENAME, yaml_config_section=SERVER_SECTION, extra="ignore", frozen=True
     )
+
+
+settings = Settings()
+
+__all__ = ["settings"]
