@@ -14,7 +14,7 @@
 
 import inject
 
-from superlinked.server.configuration.settings import Settings
+from superlinked.server.configuration.settings import settings
 from superlinked.server.service.data_loader import DataLoader
 from superlinked.server.service.file_handler_service import FileHandlerService
 from superlinked.server.service.file_object_serializer import FileObjectSerializer
@@ -26,7 +26,6 @@ def register_dependencies() -> None:
 
 
 def _configure(binder: inject.Binder) -> None:
-    settings = Settings()
     file_handler_service = FileHandlerService(settings)
     serializer = FileObjectSerializer(file_handler_service)
     binder.bind(DataLoader, DataLoader(settings))
