@@ -15,40 +15,49 @@
 import logging
 
 from structlog_sentry import SentryProcessor
+
 from superlinked.framework.common.logging import LoggerConfigurator
 from superlinked.framework.common.util.custom_structlog_processor import (
     CustomStructlogProcessor,
 )
-
-from superlinked.server.configuration.app_config import AppConfig
+from superlinked.server.configuration.settings import Settings
 
 
 class ServerLoggerConfigurator:
     @staticmethod
-    def setup_logger(app_config: AppConfig, logs_to_suppress: list[str] | None = None) -> None:
-        processors = LoggerConfigurator._get_structlog_processors(  # noqa:SLF001 Private member
-            app_config.JSON_LOG_FILE, app_config.EXPOSE_PII, app_config.LOG_AS_JSON
-        )
-        processors += [
-            CustomStructlogProcessor.drop_color_message_key,  # Drop color must be the last processor
-            SentryProcessor(event_level=logging.ERROR, active=app_config.SENTRY_ENABLE),
-        ]
-        LoggerConfigurator.configure_structlog_logger(
-            app_config.JSON_LOG_FILE,
-            processors,
-            app_config.EXPOSE_PII,
-            app_config.LOG_AS_JSON,
-        )
+    def setup_logger(settings: Settings) -> None:
+        root_logger = logging.getLogger()
+        root_logger.setLevel(settings.LOG_LEVEL)
+        handler = logging.StreamHandler()
+        formatter = logging.Formatter("%(message)s")
+        handler.setFormatter(formatter)
+        root_logger.addHandler(handler)
 
-        logging.getLogger("").setLevel(app_config.LOG_LEVEL)
+        for _log in [
+            "uvicorn",
+            "uvicorn.lifespan",
+            "uvicorn.error",
+            "uvicorn.access",
+        ]:
+            logger = logging.getLogger(_log)
+            logger.handlers.clear()
+            root_logger.addHandler(handler)
+            logger.setLevel(logging.INFO)
+            logger.propagate = True
 
-        for _log in logs_to_suppress or []:
+        for _log in ["sentence_transformers"]:
             logging.getLogger(_log).setLevel(logging.WARNING)
 
-        # Disable uvicorn logging
-        for _log in ["uvicorn", "uvicorn.error"]:
-            logging.getLogger(_log).handlers.clear()
-            logging.getLogger(_log).propagate = True
-
-        logging.getLogger("uvicorn.access").handlers.clear()
-        logging.getLogger("uvicorn.access").propagate = False
+        processors = LoggerConfigurator._get_structlog_processors(  # noqa:SLF001 Private member
+            settings.JSON_LOG_FILE, settings.EXPOSE_PII, settings.LOG_AS_JSON
+        )
+        processors += [
+            SentryProcessor(event_level=logging.ERROR, active=settings.SENTRY_ENABLE),
+            CustomStructlogProcessor.drop_color_message_key,  # Drop color must be the last processor
+        ]
+        LoggerConfigurator.configure_structlog_logger(
+            settings.JSON_LOG_FILE,
+            processors,
+            settings.EXPOSE_PII,
+            settings.LOG_AS_JSON,
+        )
