@@ -22,6 +22,8 @@ from fastapi import FastAPI, Request, Response
 from uvicorn._types import HTTPScope
 from uvicorn.protocols.utils import get_path_with_query_string
 
+from superlinked.framework.common.telemetry.telemetry_registry import TelemetryRegistry
+
 access_logger = structlog.stdlib.get_logger("api.access")
 
 
@@ -40,6 +42,7 @@ def add_timing_middleware(app: FastAPI) -> None:
             structlog.get_logger("api.error").exception("Uncaught exception")
             raise
         process_time = time.perf_counter_ns() - start_time
+        duration_ms = process_time / 1_000_000  # Convert nanoseconds to milliseconds
         status_code = response.status_code
         url = get_path_with_query_string(cast(HTTPScope, request.scope))
         client_host = request.client.host if request.client else "no-client"
@@ -59,7 +62,13 @@ def add_timing_middleware(app: FastAPI) -> None:
             version=http_version,
             client_ip=client_host,
             client_port=client_port,
-            duration=f"{process_time / 1_000_000:.2f} ms",
+            duration=f"{duration_ms:.2f} ms",
         )
+
+        telemetry_registry = TelemetryRegistry()
+        labels = {"path": request.url.path, "method": request.method, "status_code": str(status_code)}
+        telemetry_registry.record_metric("http_requests_total", 1, labels)
+        telemetry_registry.record_metric("http_request_duration_ms", duration_ms, labels)
+
         response.headers["X-Process-Time"] = str(process_time / 10**9)
         return response
