@@ -21,9 +21,10 @@ from fastapi.responses import JSONResponse
 from fastapi_restful.cbv import cbv
 from starlette import status
 
+from superlinked.framework.common.util.version_resolver import VersionResolver
 from superlinked.server.exception.exception import DataLoaderNotFoundException
+from superlinked.server.middleware.api_key_auth import verify_api_key
 from superlinked.server.service.data_loader import DataLoader
-from superlinked.server.util.version_resolver import VersionResolver
 
 router = APIRouter()
 
@@ -36,6 +37,7 @@ class ManagementRouter:
         "/health",
         summary="Returns with 200 OK, if the application is healthy",
         status_code=status.HTTP_200_OK,
+        dependencies=[Depends(verify_api_key)],
     )
     async def health_check(self) -> JSONResponse:
         return JSONResponse(content={"message": "OK"}, status_code=status.HTTP_200_OK)
@@ -44,6 +46,7 @@ class ManagementRouter:
         "/version",
         summary="Returns the current version of the application and the Superlinked framework",
         status_code=status.HTTP_200_OK,
+        dependencies=[Depends(verify_api_key)],
     )
     async def version(self) -> JSONResponse:
         version_info = {
@@ -62,6 +65,7 @@ class ManagementRouter:
             "If the data loader is not found by the given name, 404 NOT FOUND."
         ),
         status_code=status.HTTP_200_OK,
+        dependencies=[Depends(verify_api_key)],
     )
     async def load_data(self, name: str) -> JSONResponse:
         try:
@@ -80,6 +84,7 @@ class ManagementRouter:
         "/data-loader/",
         summary="Returns 200 OK with the name and config of your data loaders",
         status_code=status.HTTP_200_OK,
+        dependencies=[Depends(verify_api_key)],
     )
     async def get_data_loaders(self) -> JSONResponse:
         loaders = self.__data_loader.get_data_loaders()  # pylint: disable=no-member
